!! ## ---------------------------------------------------
!! ## 
!! ## FIND_GIBBS
!! ##
!! ## Module containing code for finding Gibbs dividing surface
!! ##
!! ## Contains
!! ## subroutine find_gibbs_slab

module find_gibbs_mod

    implicit none
    
    !! ## parameters for
    real(8)::alpha
    real(8)::slab_width, slab_width2


contains

    subroutine find_gibbs_slab(boxx,r,zplus,zminus,z_int_upper,z_int_lower)

	!! ## subroutine for finding Gibbs dividing surfaces for liquid slab

        implicit none
	
        real(8),intent(in)::boxx(3)
        real(8),intent(in)::r(:,:)
        real(8),intent(in)::zplus,zminus
        real(8),intent(out)::z_int_upper,z_int_lower

        real(8)::lz2,area
        real(8)::zcentre_lower, zcentre_upper
        real(8)::zminus_lower, zminus_upper
        real(8)::zplus_lower, zplus_upper
	
        real(8)::n_bulk,n_int_lower,n_int_upper,rho_bulk
        real(8)::zz
	
        integer::i,n

        n=size(r(1,:))
        
        !! ## set region boundaries
        !! ## find center of slab
        lz2=0.5*boxx(3)

        !! ## get upper and lower bounds on bulk region of slab
        zcentre_lower=lz2-alpha
        zcentre_upper=lz2+alpha
        
        !! ## get guess for position of upper interface
        zplus_upper=zplus+alpha
        zplus_lower=zplus-alpha

        !! ## get guess for position of lower interface
        zminus_upper=zminus+alpha
        zminus_lower=zminus-alpha

        !! ## get number of water molecules in each region
        n_int_lower=0  !! ## around lower air-water interface
        n_int_upper=0  !! ## around upper air-water interface
        n_bulk=0       !! ## in bulk of water slab

        do i=1,n

            zz=r(3,i)

            if(zz>=zcentre_lower.and.zz<=zcentre_upper)then
               n_bulk=n_bulk+1
            elseif(zz>=zplus_lower.and.zz<=zplus_upper)then
               n_int_upper=n_int_upper+1
            elseif(zz>=zminus_lower.and.zz<=zminus_upper)then
               n_int_lower=n_int_lower+1
            endif

	
        enddo

        !! ## get bulk density
        area=boxx(1)*boxx(2)
        rho_bulk=n_bulk/(2.0*alpha*area)

        !! ## get interface locations
        z_int_upper=zplus_lower+n_int_upper/(rho_bulk*area)
        z_int_lower=zminus_upper-n_int_lower/(rho_bulk*area)

      end subroutine find_gibbs_slab

end module find_gibbs_mod

