 #!/usr/bin/python

import numpy
import MDAnalysis
import find_gibbs
import surface_area
import sys

find_gibbs.find_gibbs_mod.alpha=10.0

surface_area.surface_area_mod.nx=70
surface_area.surface_area_mod.ny=70

z_inter=0.0




## define dictionary containing affinity values for different
## amino acid types
## values taken from Radzicka and Wolfenden, Biochemistry, 27, 1664
## air-water affinity values (taking PRO to be identical to VAL as this is absent)
affinityDict={'LEU':-2.28,
              'ILE':-2.15,
              'VAL':-1.99,
              'PRO':-1.99,
              'PHE':0.76,
              'MET':1.48,
              'TRP':5.88,
              'ALA':-1.94,
              'CYS':1.24,
              'GLY':-2.39,
              'TYR':6.11,
              'THR':4.88,
              'SER':5.06,
              'HIS':10.27,
              'GLN':9.38,
              'LYS':9.52,
              'ASN':9.68,
              'GLU':10.24,
              'ASP':10.95,
              'ARG':19.92}

## create universe
groFile=sys.argv[1]
xtcFile=sys.argv[2]
fileRoot=sys.argv[3]

u=MDAnalysis.Universe(groFile,xtcFile)

## get protein and water
protein=u.selectAtoms('protein')
residues=protein.residues
water=u.selectAtoms('resname SOL')

ouf1=open(fileRoot+'_com_separation.dat','w')
ouf2=open(fileRoot+'_residue_separation.dat','w')
ouf3=open(fileRoot+'_partition_eng.dat','w')
ouf4=open(fileRoot+'_surface_area.dat','w')

for res in residues:
    print >> ouf2, "## %6d %s" % (res.id,res.name)


nprotein_atoms=len(protein)
radius=numpy.zeros(nprotein_atoms)
radius_sq=numpy.zeros(nprotein_atoms)

for i in range(nprotein_atoms):
    radius[i]=surface_area.surface_area_mod.get_radius(protein[i].type)
    print i,protein[i].type,radius[i]
radius_sq=radius**2

## loop over timeframes
for ts in u.trajectory:

   lx=ts.dimensions[0]
   ly=ts.dimensions[1]
   lz=ts.dimensions[2]

   z_plus=0.5*(lz+lz/3.0)
   z_minus=0.5*(lz-lz/3.0)
   boxx=numpy.array((lx,ly,lz))
   com_protein=protein.centroid()
   cz=com_protein[2]
   z0=water.centroid()[2]
   z_int_upper,z_int_lower=find_gibbs.find_gibbs_mod.find_gibbs_slab(boxx,numpy.transpose(water.positions),z_plus,z_minus)

   dz1=z_int_upper-com_protein[2]
   dz2=com_protein[2]-z_int_lower
   print 1.0e-2*ts.frame,com_protein[2],dz1,dz2,z_int_upper,z_int_lower
   print >> ouf1, "%12.6f%12.6f%12.6f%12.6f%12.6f%12.6f" % (1.0e-2*ts.frame,com_protein[2],dz1,dz2,z_int_upper,z_int_lower)

   ## calculate partition energy
   ## loop over residues in protein
   n_partition=0
   partition_eng=0.0
   for res in residues:
        rz=res.centerOfMass()[2]
	dz1=z_int_upper-rz
	dz2=rz-z_int_lower
	print >> ouf2, "%12.6f%12d%12.6f%12.6f" % (1.0e-2*ts.frame,res.id,z_int_upper-rz,rz-z_int_lower)

        if min(dz1,dz2)<z_inter:
	    partition_eng+=affinityDict[res.name]
	    n_partition+=1

   print >> ouf3, "%12.6f%12.6f%12d" % (1.0e-2*ts.frame,partition_eng,n_partition)

   ## get surface area
   surface_area.surface_area_mod.deltax=lx/surface_area.surface_area_mod.nx
   surface_area.surface_area_mod.deltay=ly/surface_area.surface_area_mod.ny

   area_u=surface_area.surface_area_mod.calc_surface_area(z_int_upper,boxx,radius,radius_sq,numpy.transpose(protein.positions))
   area_l=surface_area.surface_area_mod.calc_surface_area(z_int_lower,boxx,radius,radius_sq,numpy.transpose(protein.positions))

   print >> ouf4, "%12.6f%12.6f%12.6f" % (1.0e-2*ts.frame,area_u,area_l)
