!! ## -------------------------------------------

module surface_area_mod

    implicit none

    real(8)::deltax,deltay
    integer::nx,ny

contains

    subroutine calc_surface_area(z_inter,boxx,radius,radius_sq,r,surface_area)

        implicit none

        real(8),intent(in)::z_inter
        real(8),intent(in)::boxx(3)
        real(8),intent(in)::radius(:),radius_sq(:)
        real(8),intent(in)::r(:,:)
        real(8),intent(out)::surface_area

        real(8)::x,y,dx,dy,dz,dr2

        integer::natom,nignore
        integer::i,ix,iy
        logical::ignore(size(radius))

        !! ## -----------------------------------------------

        natom=size(r(1,:))
        surface_area=0.0
        !! ## check whether any atom is close to the interface
        nignore=0
        ignore(:)=.false.
        do i=1,natom

                      if(abs(z_inter-r(3,i))>radius(i))then
              ignore(i)=.false.
              nignore=nignore+1
           endif

        enddo

        if(nignore>=natom)then
            return
        endif

        !! ## loop over grid points
        do ix=1,nx

           x=(ix-0.5)*deltax
           do iy=1,ny

              y=(iy-0.5)*deltay

              !! ## loop over atoms
              do i=1,natom

                 if(ignore(i))cycle

                 !! ## get distance to grid point
                 dx=x-r(1,i)
                 dx=dx-boxx(1)*anint(dx/boxx(1))
                 dy=y-r(2,i)
                 dy=dy-boxx(2)*anint(dy/boxx(2))
                 dz=z_inter-r(3,i)

                 dr2=dx*dx+dy*dy+dz*dz
                 if(dr2>radius_sq(i))cycle
                 surface_area=surface_area+deltax*deltay
                 exit
              enddo

           enddo
        enddo

    end subroutine calc_surface_area

    function get_radius(el)
        implicit none
        character(len=1)::el
        real(8)::get_radius

        if(el=='C')then
            get_radius=1.50
        elseif(el=='H')then
            get_radius=0.4
        elseif(el=='N')then
            get_radius=1.1
        elseif(el=='O')then
            get_radius=1.05
        elseif(el=='S')then
            get_radius=1.60
        else
            write(*,*)'Error: unrecognised element'
            write(*,*)el
            stop
        endif

    endfunction get_radius

end module surface_area_mod

!! ## -------------------------------------------
